@@ -70,7 +70,6 @@ class AudioImpulseRunner(ImpulseRunner):
         self.window_size = 0
         self.labels = []
 
-
     def init(self):
         model_info = super(AudioImpulseRunner, self).init()
         if model_info['model_parameters']['frequency'] == 0:
@@ -89,8 +88,10 @@ class AudioImpulseRunner(ImpulseRunner):
     def __exit__(self, type, value, traceback):
         self.closed = True
 
-    def classify(self):
+    def classify(self, data):
+        return super(CameraImpulseRunner, self).classify(data)
 
+    def classifier(self):
         with Microphone(self.sampling_rate, CHUNK_SIZE) as mic:
             generator = mic.generator()
             features = np.array([], dtype=np.uint16)
@@ -100,6 +101,6 @@ class AudioImpulseRunner(ImpulseRunner):
                     features = np.concatenate((features, data), axis=0)
                     while len(features) >= self.window_size:
                         begin = now()
-                        res = super(AudioImpulseRunner, self).classify(features[:self.window_size].tolist())
+                        res = self.classify(features[:self.window_size].tolist())
                         features = features[int(self.window_size * OVERLAP):]
                         yield res
